@@ -433,13 +433,13 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
         onUpdateAPItem();
 
     QGSettings *gsetting = new QGSettings("com.deepin.dde.control-center", QByteArray(), this);
-    connect(gsetting, &QGSettings::changed, this, [&](const QString &key) {
+    connect(gsetting, &QGSettings::changed, this, [ & ](const QString &key) {
         if (key == "wireless-scan-interval")
-            m_wirelessScanTimer->setInterval(gsetting->get("wireless-scan-interval").toInt());
+            m_wirelessScanTimer->setInterval(gsetting->get("wireless-scan-interval").toInt() * 1000);
     });
 
     connect(m_device, &WirelessDevice::destroyed, this, [ this ] {
-       this->m_device = nullptr;
+        this->m_device = nullptr;
     });
 
     connect(m_wirelessScanTimer, &QTimer::timeout, this, [ this ] {
@@ -449,11 +449,6 @@ WirelessPage::WirelessPage(WirelessDevice *dev, QWidget *parent)
 
     m_wirelessScanTimer->start(gsetting->get("wireless-scan-interval").toInt() * 1000);
 
-    QTimer::singleShot(100, this, [ = ] {
-        if (m_device)
-            m_device->scanNetwork();
-    });
-
     m_lvAP->setVisible(m_switch->checked() && QGSettings("com.deepin.dde.control-center", QByteArray(), this).get("wireless").toString() != "Hidden");
     connect(m_device, &WirelessDevice::deviceStatusChanged, this, &WirelessPage::onDeviceStatusChanged);
     updateLayout(!m_lvAP->isHidden());
