@@ -74,8 +74,19 @@ NetworkPanel::~NetworkPanel()
     NetItem *oldSelectItem = selectItem();
     if (oldSelectItem) {
         WirelessItem *item = static_cast<WirelessItem *>(oldSelectItem);
-        item->onCancel();
+        if (item) {
+            const AccessPoints *ap = item->accessPoint();
+            if (ap && ap->status() == ConnectionStatus::Activating) {
+                WirelessDevice *device = (const_cast<WirelessDevice *>(item->wirelessDevice()));
+                device->disconnectNetwork();
+            }
+        }
     }
+
+    for (NetItem *item : m_items)
+        delete item;
+
+    m_items.clear();
 }
 
 void NetworkPanel::initUi()
@@ -442,6 +453,9 @@ void NetworkPanel::updateView()
                 qApp->quit();
         });
     }
+    // 只有当列表中的数量大于1的情况下，才抛出更新完成的信号,通知网络列表显示
+    if (m_model->rowCount() > 1)
+        Q_EMIT updateFinished();
 }
 
 void NetworkPanel::refreshItems()
@@ -493,8 +507,6 @@ void NetworkPanel::refreshItems()
     m_netListView->setFixedSize(PANELWIDTH, totalHeight);
     m_centerWidget->setFixedSize(PANELWIDTH, totalHeight);
     m_applet->setFixedSize(PANELWIDTH, height);
-    if (height > 0)
-        m_applet->setObjectName("NetworkApplet");
 
     m_netListView->update();
 }
@@ -679,7 +691,7 @@ void NetworkPanel::expandPasswordInput()
             WirelessItem *wirelessItem = static_cast<WirelessItem *>(item);
             if (wirelessItem->accessPoint()
                 && (m_reconnectDev.isEmpty() || wirelessItem->wirelessDevice()->path() == m_reconnectDev)
-                && (wirelessItem->standardItem()->text() == m_reconnectSsid)) {
+                && (wirelessItem->accessPoint()->ssid() == m_reconnectSsid)) {
                 if (item != oldSelectItem) {
                     if (oldSelectItem) {
                         WirelessItem *selectItem = static_cast<WirelessItem *>(oldSelectItem);
@@ -968,13 +980,18 @@ bool NetworkDelegate::switchIsEnabled(const QModelIndex &index) const
         }
         return false;
     }
-    case NetItemType::WiredControllViewItem:
-    case NetItemType::WirelessControllViewItem: {
+    case NetItemType::WiredControllViewItem:{
         NetworkDeviceBase *device = index.data(NetItemRole::DeviceDataRole).value<NetworkDeviceBase *>();
         if (device)
             return device->isEnabled();
         break;
     }
+    case NetItemType::WirelessControllViewItem: {
+        NetworkDeviceBase *device = index.data(NetItemRole::DeviceDataRole).value<NetworkDeviceBase *>();
+        if (device)
+            return device->isEnabled() && !m_airplaneMode->enabled();
+        break;
+    }
     default:
         break;
     }
