@@ -166,7 +166,7 @@ QString DeviceManagerRealize::usingHwAdr() const
     return QString();
 }
 
-QStringList DeviceManagerRealize::ipv4() const
+const QStringList DeviceManagerRealize::ipv4()
 {
     if (!device() || !device()->isConnected() || !isEnabled())
         return QStringList();
@@ -179,7 +179,7 @@ QStringList DeviceManagerRealize::ipv4() const
     return ipv4s;
 }
 
-QStringList DeviceManagerRealize::ipv6() const
+const QStringList DeviceManagerRealize::ipv6()
 {
     if (!device() || !device()->isConnected() || !isEnabled())
         return QStringList();
@@ -729,6 +729,12 @@ ConnectionStatus DeviceManagerRealize::convertStatus(Device::State state)
 
 DeviceStatus DeviceManagerRealize::convertDeviceStatus(Device::State state)
 {
+    if (m_wDevice->type() == NetworkManager::Device::Wifi) {
+        // 如果当前网卡开启了热点，则认为它是连接断开的状态
+        NetworkManager::WirelessDevice::Ptr wirelessDevice = m_wDevice.staticCast<NetworkManager::WirelessDevice>();
+        if (wirelessDevice->mode() == NetworkManager::WirelessDevice::OperationMode::ApMode)
+            return DeviceStatus::Disconnected;
+    }
     switch (state) {
     case Device::State::Failed:
         return DeviceStatus::Failed;
