@@ -139,9 +139,6 @@ void NetworkInterProcesser::initConnection()
     connect(m_networkInter, &NetworkInter::DeviceEnabled, this, &NetworkInterProcesser::onDeviceEnableChanged);                        // 关闭设备或启用设备
 
     connect(m_networkInter, &NetworkInter::ConnectivityChanged, this, &NetworkInterProcesser::onConnectivityChanged);                  // 网络状态发生变化
-    connect(m_ipChecker, &IPConfilctChecker::conflictStatusChanged, this, [ ] (NetworkDeviceBase *device, const bool confilct) {
-        Q_EMIT device->deviceStatusChanged(confilct ? DeviceStatus::IpConfilct : device->deviceStatus());
-    });
 }
 
 NetworkDeviceBase *NetworkInterProcesser::findDevices(const QString &path) const
@@ -423,6 +420,17 @@ void NetworkInterProcesser::updateDeviceConnectiveInfo()
 
 void NetworkInterProcesser::activeConnInfoChanged(const QString &conns)
 {
+    // 当没有激活的连接时，需要更新对应的连接信息和网络详细信息为空
+    if (conns == "null") {
+        for (NetworkDeviceBase *device : m_devices){
+            DeviceInterRealize *deviceInter = static_cast<DeviceInterRealize *>(device->deviceRealize());
+            deviceInter->updateActiveConnectionInfo(QList<QJsonObject>());
+            m_networkDetails.clear();
+        }
+
+        return;
+    }
+
     QJsonParseError error;
     m_activeConnectionInfo = QJsonDocument::fromJson(conns.toUtf8(), &error).array();
     if (error.error == QJsonParseError::NoError) {
